###################################################################
########################## DESCRIPTIVES ###########################
###################################################################

library(lsr) # for cohen's d
library(heplots) # for eta square
library(effsize) # for cohen's d CIs


### Covariates

## age

# descriptives age
abc=subset(CLOCd,select=c(Vxx01:Vxx11,age_min))
abc=na.omit(abc)
mean(abc$age_min)
sd(abc$age_min)

# age differences
t.test(age_min~cond)
cohensD(CESDc.age_mis$CLOCc.age_min,CESDw.age_mis$CLOCw.age_min) #cohen's d = 0.1219325
cohen.d(CESDc.age_mis$CLOCc.age_min,CESDw.age_mis$CLOCw.age_min, pooled=TRUE,paired=FALSE,
         na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 
# CI -0.05206447  0.29592953 


## sex descriptives & differences; 1=female, 2=male
abcd=subset(CLOCd,select=c(Vxx01:Vxx11,sex))
abcd=na.omit(abcd)
abcd$sex=as.numeric(abcd$sex)
mean(abcd$sex)
sd(abcd$sex)

CLOC.sex.w <- transform(CLOC.sex.w, sex=as.numeric(sex))
CLOC.sex.c <- transform(CLOC.sex.c, sex=as.numeric(sex))
t.test(CLOC.sex.w$sex,CLOC.sex.c$sex)
cohensD(CLOC.sex.w$sex,CLOC.sex.c$sex) #cohen's d = 0.04628899
cohen.d(CLOC.sex.c$sex,CLOC.sex.w$sex, pooled=TRUE,paired=FALSE,
        na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 
# CI -0.1275699  0.2201478 


## Functional health index (not reported in manuscript)
FS=data.frame(CLOCd$Vxx01,CLOCd$Vxx02,CLOCd$Vxx03,CLOCd$Vxx04,CLOCd$Vxx05,CLOCd$Vxx06,CLOCd$Vxx07,CLOCd$Vxx08,CLOCd$Vxx09,CLOCd$Vxx10,CLOCd$Vxx11,cond,funct.status)
FS=na.omit(FS)
FS=subset(FS,select=c(cond,funct.status))
dim(FS) # N=515, final sample
t.test(FS$funct.status[cond=="widow"],FS$funct.status[cond=="control"])
sd(FS$funct.status[cond=="control"])


## How many control participants are married to each other? 
CLOCc.married=subset(CLOCc,select=c(V1,V815,Vxx01,Vxx02,Vxx03,Vxx04,Vxx05,Vxx06,Vxx07,Vxx08,Vxx09,Vxx10,Vxx11))
CLOCc.married=na.omit(CLOCc.married)
dim(CLOCc.married)
id=CLOCc.married$V1
ids=CLOCc.married$V815
length(which(ids %in% id)==T)
v=as.vector(which(ids %in% id))
m=cbind(id,ids)
m[v,]


## Time between baseline and follow up measurements

# Widows: time between baseline and wave1 for widows
mean(gap.w$gap.w.CLOCw.gap1) 
sd(gap.w$gap.w.CLOCw.gap1)

# Controls: time between baseline and average control measurement
gap.c #copy table to excel, take only the FIRST measurement for each participant, build means and SDs
      #anova for group differences conducted in SPSS
      #file called "control group info.xlsx"; save resulting columnn in gap.c.csv"
gap.c.new<-read.csv("gap.c.csv", head=T)
str(gap.c.new)
t.test(gap.w$gap.w.CLOCw.gap1,gap.c.new$gap.new)
cohensD(gap.w$gap.w.CLOCw.gap1,gap.c.new$gap.new) #cohen's d = 0.83
cohen.d(gap.c.new$gap.new, gap.w$gap.w.CLOCw.gap1, pooled=TRUE,paired=FALSE,
        na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 
# CI 0.6528007 1.0152689 



### Symptom analysis

# Figure 1: plot symptoms (few additional changes performed in Inkscape)
dev.off()
par(xpd=T)
barplot(rbind(colMeans(CESDw_mis),colMeans(CESDc_mis)),col=c("black","lightgrey"),
        names=symptoms,beside=T,axes=F,ann=F, xpd = FALSE,axisnames=F, ylim=c(0,1))
axis(1, at=seq(2,32,3), lab=symptoms,las=2,cex.axis=1.0)
axis(2)
legend(27,1,c("Widows","Controls"),fill=c("black","lightgrey"),box.col = "white") 

# Sum score comparison (reversed positive items)
CESDr=data.frame(Vxx01,Vxx02,Vxx03,Vxx04r,Vxx05,Vxx06,Vxx07r,Vxx08,Vxx09,Vxx10,Vxx11)
CESDrw_mis=na.omit(subset(CESDr,(cond=="widow")))
CESDrc_mis=na.omit(subset(CESDr,(cond=="control")))
mean(rowSums(CESDrw_mis))
mean(rowSums(CESDrc_mis))
t.test(rowSums(CESDrw_mis),rowSums(CESDrc_mis))
sd(rowSums(CESDrw_mis))
sd(rowSums(CESDrc_mis))
cohensD(rowSums(CESDrw_mis),rowSums(CESDrc_mis)) #cohen's d = 0.4846711
cohen.d(rowSums(CESDrw_mis),rowSums(CESDrc_mis), pooled=TRUE,paired=FALSE,
        na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 
# CI 0.3083024 0.6610399 

# MANOVA symptom comparison ##
fit <- manova(cbind(Vxx01,Vxx02,Vxx03,Vxx04,Vxx05,Vxx06,Vxx07,Vxx08,Vxx09,Vxx10,Vxx11) ~ cond)
summary(fit)
summary.aov(fit)
etasq(fit) # eta^2 = 0.28, CI (0.25, 0.31)
#to obtain CI follow http://stats.stackexchange.com/questions/28247/confidence-interval-for-eta2?rq=1
#squareroot 0.28 = 0.5292; r to z = 0.589, SE = 0.0442; LWR 0.5448; UPR = 0.6332; 
#z to r:  LWR = 0.497; UPR = 0.560; squared LWR 0.247 UPR 0.3136


## Baseline symptom differences

# Difference in CESD sum score 
mean(rowSums(CLOC.bw)) # n=236
mean(rowSums(CLOC.bc)) # n=245
t.test(rowSums(CLOC.bw),rowSums(CLOC.bc))
sd(rowSums(CLOC.bw))
sd(rowSums(CLOC.bc))
cohensD(rowSums(CLOC.bw),rowSums(CLOC.bc)) #cohen's d = 0.112659
cohen.d(rowSums(CLOC.bw),rowSums(CLOC.bc), pooled=TRUE,paired=FALSE,
        na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 
# CI -0.06163017  0.28694874 

# Manova
fit2 <- manova(cbind(CLOC.base$V247d,CLOC.base$V248d,CLOC.base$V249d,CLOC.base$V250d,CLOC.base$V251d,CLOC.base$V252d,CLOC.base$V253d,CLOC.base$V254d,CLOC.base$V255d,CLOC.base$V256d,CLOC.base$V257d) ~ CLOC.base$cond)
summary(fit2)
etasq(fit2) # eta^2 = 0.03 (CI .02, .05)
#to obtain CI follow http://stats.stackexchange.com/questions/28247/confidence-interval-for-eta2?rq=1
#squareroot 0.03 = 0.173; r to z = 0.1748, SE = 0.0442; LWR .1306; UPR = .219; 
#z to r:  LWR = 0.130; UPR = 0.216; squared LWR .017 UPR .046










### Additional analyses requested by reviewer

## Compare control groups across waves;

#age
dim(c.w1)
dim(c.w2)
dim(c.w3)
mean(c.w1$age_min)
sd(c.w1$age_min)
mean(c.w2$age_min)
sd(c.w2$age_min)
mean(c.w3$age_min)
sd(c.w3$age_min)

t.test(c.w1$age_min,c.w2$age_min) #p=.578
cohensD(c.w1$age_min,c.w2$age_min) 
cohen.d(c.w1$age_min,c.w2$age_min, pooled=TRUE,paired=FALSE, na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 

t.test(c.w1$age_min,c.w3$age_min) #p=.008
cohensD(c.w1$age_min,c.w3$age_min) 
kiki<-cohen.d(c.w1$age_min,c.w3$age_min, pooled=TRUE,paired=FALSE, na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 

t.test(c.w2$age_min,c.w3$age_min) #p=.012
cohensD(c.w2$age_min,c.w3$age_min) 
cohen.d(c.w2$age_min,c.w3$age_min, pooled=TRUE,paired=FALSE, na.rm=FALSE, hedges.correction=FALSE, conf.level=0.95) 


#sex
mean(c.w1$sex)
sd(c.w1$sex)
mean(c.w2$sex)
sd(c.w2$sex)
mean(c.w3$sex)
sd(c.w3$sex)
t.test(c.w1$sex,c.w2$sex) #p=.46
t.test(c.w1$sex,c.w3$sex) #p=.792
t.test(c.w2$sex,c.w3$sex) #p=.373

#symptom sumscores
dev.off()
par(xpd=T)
barplot(rbind(colMeans(c.w1.s),colMeans(c.w2.s), colMeans(c.w3.s)),col=c("black","lightgrey","grey"),
        names=symptoms,beside=T,axes=F,ann=F, xpd = FALSE,axisnames=F, ylim=c(0,1))
axis(1, at=seq(1,44,4), lab=symptoms,las=2,cex.axis=1.0)
axis(2)
legend(27,1,c("Wave1","Wave2","Wave3"),fill=c("black","lightgrey", "grey"),box.col = "white") 

mean(rowSums(c.w1.r))
mean(rowSums(c.w2.r))
mean(rowSums(c.w3.r))
t.test(rowSums(c.w1.r),rowSums(c.w1.r)) #p=1
t.test(rowSums(c.w1.r),rowSums(c.w3.r)) #p=.995
t.test(rowSums(c.w2.r),rowSums(c.w3.r)) #p=.892

#MANOVA
M.w1w2<- manova(cbind(d.w1w2$Vxx01,
                      d.w1w2$Vxx02,
                      d.w1w2$Vxx03,
                      d.w1w2$Vxx04,
                      d.w1w2$Vxx05,
                      d.w1w2$Vxx06,
                      d.w1w2$Vxx07,
                      d.w1w2$Vxx08,
                      d.w1w2$Vxx09,
                      d.w1w2$Vxx10,
                      d.w1w2$Vxx11) ~ d.w1w2$w1w2)
summary(M.w1w2)

M.w1w3<- manova(cbind(d.w1w3$Vxx01,
                      d.w1w3$Vxx02,
                      d.w1w3$Vxx03,
                      d.w1w3$Vxx04,
                      d.w1w3$Vxx05,
                      d.w1w3$Vxx06,
                      d.w1w3$Vxx07,
                      d.w1w3$Vxx08,
                      d.w1w3$Vxx09,
                      d.w1w3$Vxx10,
                      d.w1w3$Vxx11) ~ d.w1w3$w1w3)
summary(M.w1w3)

M.w2w3<- manova(cbind(d.w2w3$Vxx01,
                      d.w2w3$Vxx02,
                      d.w2w3$Vxx03,
                      d.w2w3$Vxx04,
                      d.w2w3$Vxx05,
                      d.w2w3$Vxx06,
                      d.w2w3$Vxx07,
                      d.w2w3$Vxx08,
                      d.w2w3$Vxx09,
                      d.w2w3$Vxx10,
                      d.w2w3$Vxx11) ~ d.w2w3$w2w3)
summary(M.w2w3)
summary.aov(M.w2w3)
etasq(M.w2w3) # eta^2 = 0.1323169 (CI .09, .18)
#to obtain CI follow http://stats.stackexchange.com/questions/28247/confidence-interval-for-eta2?rq=1
# calculator for r-z:http://vassarstats.net/tabs.html#fisher
# squareroot 0.13 = 0.361; r to z = 0.378, SE = 0.0725; LWR .301; UPR = .451; 
# calculator for z-r: http://onlinestatbook.com/calculators/fisher_z.html
#z to r:  LWR = 0.292; UPR = 0.423; squared LWR .085 UPR .179



