###################################################################
######################## Network analysis #########################
###################################################################

library(IsingFit)
library(IsingSampler)
library(qgraph)
library(reshape)

datapcalg1=subset(CLOCd, select=c(Vxx01,Vxx02,Vxx03,Vxx04,Vxx05,Vxx06,Vxx07,Vxx08,Vxx09,Vxx10,Vxx11,cond))

datapcalg1=na.omit(datapcalg1) 

#rename variables & data first so the plot has the right variable names
datapcalg1<-rename(datapcalg1, c(Vxx01="depr", Vxx02="effort", Vxx03="sleep", Vxx04="happy", Vxx05="lonely", Vxx06="unfr", Vxx07="enjoy", Vxx08="appet", Vxx09="sad", Vxx10="dislike", Vxx11="getgo", cond="loss"))

datapcalg1$loss=as.numeric(datapcalg1$loss)
datapcalg1$loss[datapcalg1$loss==1]=0
datapcalg1$loss[datapcalg1$loss==2]=1
dim(datapcalg1) #n=515

dev.off()
ising.plot<-IsingFit(datapcalg1, family="binomial", plot=T, progressbar=T) 
N <- ncol(ising.plot$weiadj )
set.seed(3)
qgraph(ising.plot$weiadj,layout="spring", labels=colnames(datapcalg1), layout.par=list(init = matrix(rnorm(N*2),N,2)), vsize=7)
# second plot circle for comparison with smaller sample network requetsed by francis during review process of JAbnPsych (see below)
# qgraph(ising.plot$weiadj,layout="circle", labels=colnames(datapcalg1), layout.par=list(init = matrix(rnorm(N*2),N,2)), vsize=7)


write.csv(ising.plot$weiadj, "test.csv")



##### rerun analyses excluding 42 people from wave 3 in control group for reviewer.

datapcalg2=subset(CLOCd, select=c(Vxx01,Vxx02,Vxx03,Vxx04,Vxx05,Vxx06,Vxx07,Vxx08,Vxx09,Vxx10,Vxx11,cond,gap1,gap2,gap3))
datapcalg2[datapcalg2 == 9999] <- NA
dim(datapcalg2)

datapcalg2$gap2[cond == "control" & datapcalg2$gap1>-5 & datapcalg2$gap2>-5] <- NA
datapcalg2$gap3[cond == "control" & datapcalg2$gap1>-5 & datapcalg2$gap2>-5 & datapcalg2$gap3>-5 ] <- NA
datapcalg2$gap3[cond == "control" & datapcalg2$gap1>-5 & datapcalg2$gap3>-5 ] <- NA
datapcalg2$gap3[cond == "control" & datapcalg2$gap2>-5 & datapcalg2$gap3>-5 ] <- NA
dim(datapcalg2)

datapcalg2$delete[cond== "control" & !is.na(datapcalg2$gap3)] <- 1
sum(!is.na(datapcalg2$delete)) #42 people should be deleted
datapcalg2= subset(datapcalg2, is.na(datapcalg2$delete)) # 42 people deleted

datapcalg2=subset(datapcalg2, select=c(Vxx01,Vxx02,Vxx03,Vxx04,Vxx05,Vxx06,Vxx07,Vxx08,Vxx09,Vxx10,Vxx11,cond))
dim(datapcalg2)

datapcalg2<-rename(datapcalg2, c(Vxx01="depr", Vxx02="effort", Vxx03="sleep", Vxx04="happy", Vxx05="lonely", Vxx06="unfr", Vxx07="enjoy", Vxx08="appet", Vxx09="sad", Vxx10="dislike", Vxx11="getgo", cond="loss"))

datapcalg2$loss=as.numeric(datapcalg2$loss)
datapcalg2$loss[datapcalg2$loss==1]=0
datapcalg2$loss[datapcalg2$loss==2]=1

datapcalg2=na.omit(datapcalg2)
dim(datapcalg2) #n=473= (515-42); final sample for test

#export for mplus
data2.mplus=subset(datapcalg2)   
write.foreign(data2.mplus,"export_data_mplus_small.txt", "mydata.sps", package="SPSS")

dev.off()
ising.plot<-IsingFit(datapcalg2, family="binomial", plot=T, progressbar=T) 
N <- ncol(ising.plot$weiadj )
set.seed(3)
qgraph(ising.plot$weiadj,layout="circle", labels=colnames(datapcalg2), layout.par=list(init = matrix(rnorm(N*2),N,2)), vsize=7)

# compare old and new
dev.off()
qgraph(ising.plot$weiadj,layout="circle", labels=colnames(datapcalg2), layout.par=list(init = matrix(rnorm(N*2),N,2)), vsize=7)





